summaryrefslogtreecommitdiffstats
path: root/kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h')
-rw-r--r--kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h b/kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h
index fb9cff70..89a32571 100644
--- a/kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h
+++ b/kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h
@@ -22,10 +22,11 @@ Andrea Rizzi
class KDBSearchEngine2 : public SearchEngine
{
Q_OBJECT
+ TQ_OBJECT
public:
- KDBSearchEngine2(TQObject *parent=0, const char *name=0);
+ KDBSearchEngine2(TQObject *tqparent=0, const char *name=0);
virtual ~KDBSearchEngine2();
//init if needed.
@@ -77,9 +78,9 @@ class KDBSearchEngine2 : public SearchEngine
* search engine. The returned widget should not be bigger than
* 400x400. If you need more space, you maybe want to use
* a tabbed widget.
* @param parent the parent of the returned widget
*/
- virtual PrefWidget* preferencesWidget(TQWidget *parent);
+ virtual PrefWidget* preferencesWidget(TQWidget *tqparent);
/** @returns information about this SearchEngine */
virtual const KAboutData *about() const;
@@ -77,9 +78,9 @@ class KDBSearchEngine2 : public SearchEngine
* 400x400. If you need more space, you maybe want to use
* a tabbed widget.
- * @param parent the parent of the returned widget
+ * @param tqparent the tqparent of the returned widget
*/